@@ -179,11 +179,13 @@ package OP::ExtID;
 use strict;
 use warnings;
 
-use Perl6::Subs;
-
 use base qw| OP::ID |;
 
-method assert(OP::Class $class: *@rules) {
+# method assert(OP::Class $class: *@rules) {
+sub assert {
+  my $class = shift;
+  my @rules = @_;
+
   my $externalClass = shift @rules;
   my $query = $rules[0];
 
